#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pydyf']

package_data = \
{'': ['*']}

extras_require = \
{'doc': ['sphinx', 'sphinx_rtd_theme'],
 'test': ['pytest',
          'pytest-cov',
          'pytest-flake8',
          'pytest-isort',
          'coverage[toml]',
          'pillow']}

setup(name='pydyf',
      version='0.1.1',
      description='A low-level PDF generator.',
      author=None,
      author_email='CourtBouillon <contact@courtbouillon.org>',
      url=None,
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
      python_requires='>=3.6',
     )
